import excel Internet.xlsx, clear
keep if A=="Internet"
rename A type
rename B hhcomsub
rename C address
rename D zipcode
rename E speed1
rename F price1
rename G term1
rename H speed2
rename I price2
rename J term2
rename K speed3
rename L price3
rename M term3
rename N speed4
rename O price4
rename P term4
rename Q speed5
rename R price5
rename S term5
rename T speed6
rename U price6
rename V term6
rename W speed7
rename X price7
rename Y term7
rename Z speed8
rename AA price8
rename AB term8
rename AC speed9
rename AD price9
rename AE term9

* Drop duplicate addresses, reshape
egen uniqadd=group(address zipcode)
reshape long speed price term, i(uniqadd) j(j)
drop if speed==""

* Clean 'speed' and 'channel' just to contain numbers
replace speed=regexs(2) if regexm(speed, "^([^0-9]*)([0-9]+)([^0-9]*)$")
destring speed, replace

* Clean price and contract term
destring price, replace ignore("$")
replace term="0" if strpos(term,"No Term")!=0
replace term="1" if strpos(term,"1-Year")!=0
replace term="2" if strpos(term,"2-Year")!=0
destring term, replace

* Clean scraping errors
sort uniqadd speed price
drop if uniqadd==uniqadd[_n+1] & speed==speed[_n+1]

* Make hhcomsub dummy (for whether household subscribes to Comcast)
replace hhcomsub="0" if hhcomsub=="Not Subscriber"
replace hhcomsub="1" if hhcomsub=="Subscriber"
destring hhcomsub, replace

* Correct prices for term
replace price=price+10 if term==1
replace price=price+20 if term==2

* Begin merging 
merge m:m zipcode using VerizonZipcode.dta
keep if _m==3
drop _m

* Drop areas Verizon sold to Frontier
drop if dmaname=="FT.MYERS-NAPLES"
drop if dmaname=="TAMPA-ST.PETE(SARASOTA)"

* Merge with controls
merge m:m zipcode using zipincome2016.dta
keep if _m==3
drop _m
merge m:m zipcode using BellGTEzipcode.dta
drop _m

* Create a string variable representing the exact menu offering in terms of speeds
tab speed, generate(speed_dummy)
forval i=1/18 {
	egen max_speed`i'=max(speed_dummy`i'), by(uniqadd)
	}
gen menu=""
forval i=1/18 {
replace menu=menu+"`i'" if max_speed`i'==1
}

* Analysis
* Drop speeds that are almost never offered
drop if speed==5 | speed==8 | speed==16 | speed==50 | speed==105

estimates clear
gen ones=1
gen lnprice=log(price)
gen lnspeed=log(speed)
gen lnincome=log(meanincome)

* Create household-level measures
egen numspeedoffers=total(ones), by(uniqadd)
gen lnnumspeedoffers=log(numspeedoffers)
egen uniqadd_speed_grp=group(uniqadd speed)

egen medspeedoffered=median(speed), by(uniqadd)
egen medpriceoffered=median(price), by(uniqadd)
egen avgspeedoffered=mean(speed), by(uniqadd)
egen avgpriceoffered=mean(price),by(uniqadd)
gen lnavgspeedoffered=log(avgspeedoffered)

egen speedsd=sd(speed), by(uniqadd)
egen pricesd=sd(price), by(uniqadd)
gen lnspeedsd=log(speedsd)

gen cv=speedsd/avgspeedoffered
gen pricecv=pricesd/avgpriceoffered

gen mq=0
replace mq=1 if speed==2000
egen maxqual=max(mq), by(uniqadd)

* Table 3
preserve
collapse maxqual numspeedoffers medspeedoffered medpriceoffered avgspeedoffered avgpriceoffered speedsd pricesd vdummy cv pricecv, by(uniqadd)
egen numspeedsd=sd(numspeedoffers), by(vdummy maxqual)
egen avgnumspeedoffers_agg=mean(numspeedoffers)
gen cv_agg=numspeedsd/avgnumspeedoffers

summ medspeedoffered avgspeedoffered cv if vdummy==0
summ medspeedoffered avgspeedoffered cv if vdummy==1
summ medpriceoffered avgpriceoffered pricecv if vdummy==0
summ medpriceoffered avgpriceoffered pricecv if vdummy==1
summ numspeedoffers cv_agg if vdummy==0, d
summ numspeedoffers cv_agg if vdummy==1, d
summ medspeedoffered avgspeedoffered cv if vdummy==0 & maxqual==1
summ medspeedoffered avgspeedoffered cv if vdummy==1 & maxqual==1
summ medpriceoffered avgpriceoffered pricecv if vdummy==0 & maxqual==1
summ medpriceoffered avgpriceoffered pricecv if vdummy==1 & maxqual==1
summ numspeedoffers cv_agg if vdummy==0 & maxqual==1, d
summ numspeedoffers cv_agg if vdummy==1 & maxqual==1, d
restore

* Table 5
preserve
collapse lnnumspeedoffers lnavgspeedoffered lnspeedsd vdummy lnincome (firstnm) dmaname (firstnm) zipcode, by(uniqadd)
reg lnnumspeedoffers vdummy lnincome, cluster(zipcode)
estimates store reg0a
xi: areg lnnumspeedoffers vdummy lnincome, absorb(dmaname) cluster(zipcode)
estimates store reg0b
reg lnavgspeedoffered vdummy lnincome, cluster(zipcode)
estimates store reg0c
xi: areg lnavgspeedoffered vdummy lnincome, absorb(dmaname) cluster(zipcode)
estimates store reg0d
reg lnspeedsd vdummy lnincome, cluster(zipcode)
estimates store reg0e
xi: areg lnspeedsd vdummy lnincome, absorb(dmaname) cluster(zipcode)
estimates store reg0f
estout reg0a reg0b reg0c reg0d reg0e reg0f, style(tex) stats(r2 N) cells(b(star fmt(2)) se(par fmt(2))) starlevels(* 0.10 ** 0.05 *** 0.01) varlabels(_cons Constant vdummy \textit{Verizon} lnspeed \textit{Log(DownloadSpeed)} inter_lnspeedvdummy \textit{Verizon*Log(DownloadSpeed)} lnchannel \textit{Log(NumChannels)} inter_lnchannel \textit{Verizon*Log(NumChannels)} lnincome \textit{Log(Income)})
restore

* Interaction term
gen inter_lnspeedvdummy=lnspeed*vdummy

* Generate IV variables
egen dmag=group(dmaname)
egen avgadummy=mean(adummy), by(dmaname)
egen avgbelldummy=mean(avgbell), by(dmaname)
egen avggtedummy=mean(avggte), by(dmaname)
egen zipcode_n=group(zipcode)
gen z1=avgadummy*lnspeed
gen z2=avgbelldummy*lnspeed
gen z3=avggtedummy*lnspeed

* Table 8
eststo clear
estpost summ price vdummy speed meanincome avgbelldummy avggtedummy
est store a
esttab a, replace collabels(\multicolumn{1}{c}{{Mean}} \multicolumn{1}{c}{{Std.Dev.}} \multicolumn{1}{l}{{Obs}}) cells("mean(fmt(2)) sd(fmt(2)) min(fmt(0)) max(fmt(0)) count(fmt(0))") label nonumber f noobs alignment(S) booktabs

* Table 9
xi: qui reg lnprice lnspeed vdummy lnincome, cluster(zipcode)
estimates store reg1a
xi: qui areg lnprice lnspeed c.lnspeed#i.vdummy, absorb(zipcode) cluster(zipcode) noomitted
estimates store reg1b
qui reghdfe lnprice lnspeed (inter_lnspeed = z2 z3), absorb(zipcode_n) cluster(dmag) 
estimates store reg1c
xi: qui reg lnprice lnspeed vdummy lnincome if maxqual==1, cluster(zipcode)
estimates store reg1d
xi: qui areg lnprice lnspeed c.lnspeed#i.vdummy if maxqual==1, absorb(zipcode) cluster(zipcode) noomitted
estimates store reg1e
qui reghdfe lnprice lnspeed (inter_lnspeed = z2 z3) if maxqual==1, absorb(zipcode_n) cluster(dmag)
estimates store reg1f
estout reg1a reg1b reg1c reg1d reg1e reg1f, style(tex) stats(r2 N) cells(b(star fmt(2)) se(par fmt(2))) starlevels(* 0.10 ** 0.05 *** 0.01) varlabels(_cons Constant vdummy \textit{Verizon} lnspeed \textit{Log(DownloadSpeed)} inter_lnspeedvdummy \textit{Verizon*Log(DownloadSpeed)} lnchannel \textit{Log(NumChannels)} inter_lnchannel \textit{Verizon*Log(NumChannels)} lnincome \textit{Log(Income)})


