import excel Mixed.xlsx, clear
keep if A=="TV,Internet"
rename A type
rename B hhcomsub
rename C address
rename D zipcode
rename E speed1
rename F price1
rename G term1
rename H channel1
rename I speed2
rename J price2
rename K term2
rename L channel2
rename M speed3
rename N price3
rename O term3
rename P channel3
rename Q speed4
rename R price4
rename S term4
rename T channel4
rename U speed5
rename V price5
rename W term5
rename X channel5
rename Y speed6
rename Z price6
rename AA term6
rename AB channel6
rename AC speed7
rename AD price7
rename AE term7
rename AF channel7
rename AG speed8
rename AH price8
rename AI term8
rename AJ channel8
rename AK speed9
rename AL price9
rename AM term9
rename AN channel9
rename AO speed10
rename AP price10
rename AQ term10
rename AR channel10
rename AS speed11
rename AT price11
rename AU term11
rename AV channel11
rename AW speed12
rename AX price12
rename AY term12
rename AZ channel12
rename BA speed13
rename BB price13
rename BC term13
rename BD channel13
rename BE speed14
rename BF price14
rename BG term14
rename BH channel14
rename BI speed15
rename BJ price15
rename BK term15
rename BL channel15
rename BM speed16
rename BN price16
rename BO term16
rename BP channel16
rename BQ speed17
rename BR price17
rename BS term17
rename BT channel17

* Reshape
egen uniqadd=group(address zipcode)
reshape long speed price term channel, i(uniqadd) j(j)
drop if speed==""

* Clean scraping errors (download speeds in channel column for example)
drop if strpos(speed, "Channel")!=0
drop if strpos(channel, "Mbps")!=0

* Make hhcomsub dummy
replace hhcomsub="0" if hhcomsub=="Not Subscriber"
replace hhcomsub="1" if hhcomsub=="Subscriber"
destring hhcomsub, replace

* Clean price and contract term
destring price, replace ignore("$")
replace term="0" if strpos(term,"No Term")!=0
replace term="1" if strpos(term,"1-Year")!=0
replace term="2" if strpos(term,"2-Year")!=0
destring term, replace

* Clean 'speed' and 'channel' just to contain numbers
replace speed=regexs(2) if regexm(speed, "^([^0-9]*)([0-9]+)([^0-9]*)$")
replace channel=regexs(2) if regexm(channel, "^([^0-9]*)([0-9]+)([^0-9]*)$")
destring speed channel, replace

* Correct prices for term
replace price=price+10 if term==1
replace price=price+20 if term==2

* Begin merging 
merge m:m zipcode using VerizonZipcode.dta
keep if _m==3
drop _m
* Drop areas Verizon sold to Frontier
drop if dmaname=="FT.MYERS-NAPLES"
drop if dmaname=="TAMPA-ST.PETE(SARASOTA)"

merge m:m address zipcode using VerizonHHSubs.dta
drop if _m==2
drop _m

merge m:m zipcode using zipincome2016.dta
keep if _m==3
drop _m

merge m:m zipcode using BellGTEzipcode.dta
drop _m

* Drop speeds that are almost never offered
drop if speed==16 | speed==8 | speed==105 | speed==1000 | speed==50 | speed==250 | channel==45

estimates clear
gen ones=1
gen lnprice=log(price)
gen lnspeed=log(speed)
gen lnchannel=log(channel)
gen lnincome=log(meanincome)
* Interaction terms
gen inter_lnspeedvdummy=lnspeed*vdummy
gen inter_lnchannelvdummy=lnchannel*vdummy

* Create household-level measures; Broadband
egen numoffers=total(ones), by(uniqadd)
gen lnnumoffers=log(numoffers)

egen medspeedoffered=median(speed), by(uniqadd)
egen avgspeedoffered=mean(speed), by(uniqadd)
gen lnavgspeedoffered=log(avgspeedoffered)

egen speedsd=sd(speed), by(uniqadd)
gen lnspeedsd=log(speedsd)

gen twogb=0
replace twogb=1 if speed==2000
egen twogbadd=max(twogb), by(uniqadd)

* Create household-level measures; TV
egen medchanneloffered=median(channel), by(uniqadd)
egen avgchannelsoffered=mean(channel), by(uniqadd)
gen lnavgchannelsoffered=log(avgchannelsoffered)

egen channelsd=sd(channel), by(uniqadd)
gen lnchannelsd=log(channelsd)

gen mq=0
replace mq=1 if channel==260
egen maxqual=max(mq), by(uniqadd)

* Table 7
destring zipcode, replace
egen dmagroup=group(dmaname)
preserve
collapse lnnumoffers lnavgchannelsoffered lnavgspeedoffered vdummy lnincome zipcode dmagroup, by(uniqadd)
reg lnnumoffers vdummy lnincome, cluster(zipcode)
estimates store reg0a
xi: areg lnnumoffers vdummy lnincome, absorb(dmagroup) cluster(zipcode)
estimates store reg0b
reg lnavgchannelsoffered vdummy lnincome, cluster(zipcode)
estimates store reg0c
xi: areg lnavgchannelsoffered vdummy lnincome, absorb(dmagroup) cluster(zipcode)
estimates store reg0d
reg lnavgspeedoffered vdummy lnincome, cluster(zipcode)
estimates store reg0e
xi: areg lnavgspeedoffered vdummy lnincome, absorb(dmagroup) cluster(zipcode)
estimates store reg0f
estout reg0a reg0b reg0c reg0d reg0e reg0f, style(tex) stats(r2 N) cells(b(star fmt(2)) se(par fmt(2))) starlevels(* 0.10 ** 0.05 *** 0.01) varlabels(_cons Constant vdummy \textit{Verizon} lnspeed \textit{Log(DownloadSpeed)} inter_lnspeedvdummy \textit{Verizon*Log(DownloadSpeed)} lnchannel \textit{Log(NumChannels)} inter_lnchannel \textit{Verizon*Log(NumChannels)} lnincome \textit{Log(Income)})
estimates clear
restore

* IVs
egen dmag=group(dmaname)
egen avgbelldummy=mean(avgbell), by(dmaname)
egen avggtedummy=mean(avggte), by(dmaname)
egen zipcode_n=group(zipcode)
gen z2bb=(avgbelldummy)*lnspeed
gen z3bb=(avggtedummy)*lnspeed
gen z2tv=(avgbelldummy)*lnchannel
gen z3tv=(avggtedummy)*lnchannel
gen zbb=(avgbelldummy+avggtedummy)*lnspeed
gen ztv=(avgbelldummy+avggtedummy)*lnchannel

* Table 8
eststo clear
estpost summ price vdummy speed channel meanincome avgbelldummy avggtedummy
est store a
esttab a, replace collabels(\multicolumn{1}{c}{{Mean}} \multicolumn{1}{c}{{Std.Dev.}} \multicolumn{1}{l}{{Obs}}) cells("mean(fmt(2)) sd(fmt(2)) min(fmt(0)) max(fmt(0)) count(fmt(0))") label nonumber f noobs alignment(S) booktabs

* Table 11
xi: qui reg lnprice lnspeed lnchannel vdummy lnincome, cluster(zipcode)
estimates store reg1a
xi: qui areg lnprice lnspeed lnchannel c.lnspeed#i.vdummy c.lnchannel#i.vdummy, absorb(zipcode) cluster(zipcode) noomitted
estimates store reg1b
qui reghdfe lnprice lnspeed lnchannel (inter_lnspeed inter_lnchannel = zbb ztv) , absorb(zipcode_n) cluster(dmag)
estimates store reg1c
estout reg1a reg1b reg1c, style(tex) stats(r2 N) cells(b(star fmt(2)) se(par fmt(2))) starlevels(* 0.10 ** 0.05 *** 0.01) varlabels(_cons Constant vdummy \textit{Verizon} lnspeed \textit{Log(DownloadSpeed)} inter_lnspeedvdummy \textit{Verizon*Log(DownloadSpeed)} lnchannel \textit{Log(NumChannels)} inter_lnchannel \textit{Verizon*Log(NumChannels)} lnincome \textit{Log(Income)})
estimates clear

* TABLE 14. 
* First stage results and reduced form
qui reghdfe inter_lnspeed zbb ztv lnspeed lnchannel, absorb(zipcode_n) cluster(dmag)
estimates store reg2a
qui reghdfe inter_lnchannel ztv zbb lnspeed lnchannel, absorb(zipcode_n) cluster(dmag)
estimates store reg2b
* Regression on reduced form
qui reghdfe lnprice lnspeed lnchannel zbb ztv , absorb(zipcode_n) cluster(dmag)
estimates store reg2c
estout reg2a reg2b reg2c, style(tex) stats(r2 N) cells(b(star fmt(2)) se(par fmt(2))) starlevels(* 0.10 ** 0.05 *** 0.01) varlabels(_cons Constant vdummy \textit{Verizon} lnspeed \textit{Log(DownloadSpeed)} inter_lnspeedvdummy \textit{Verizon*Log(DownloadSpeed)} lnchannel \textit{Log(NumChannels)} inter_lnchannel \textit{Verizon*Log(NumChannels)} lnincome \textit{Log(Income)})

*********************************************************
* Code for robustness to Viewership as TV quality metric. 
gen economy=0
replace economy=1 if channel==100
gen starter=0
replace starter=1 if channel==140
gen preferred=0
replace preferred=1 if channel==220
gen premier=0
replace premier=1 if channel==260

merge m:m economy starter preferred using ChannelBundleQualities.dta

* Table 13
qui reg channelquality channel
predict yhat
replace lnchannel=log(yhat)
replace inter_lnchannel=lnchannel*vdummy
replace z2tv=(avgbelldummy)*lnchannel
replace z3tv=(avggtedummy)*lnchannel
replace ztv=(avgbelldummy+avggtedummy)*lnchannel

xi: qui reg lnprice lnspeed lnchannel vdummy lnincome, cluster(zipcode)
estimates store reg3a
xi: qui areg lnprice lnspeed lnchannel c.lnspeed#i.vdummy c.lnchannel#i.vdummy, absorb(zipcode) cluster(zipcode) noomitted
estimates store reg3b
qui reghdfe lnprice lnspeed lnchannel (inter_lnspeed inter_lnchannel = z2bb z3bb z2tv z3tv) , absorb(zipcode_n) cluster(dmag)
estimates store reg3c
estout reg3a reg3b reg3c, style(tex) stats(r2 N) cells(b(star fmt(2)) se(par fmt(2))) starlevels(* 0.10 ** 0.05 *** 0.01) varlabels(_cons Constant vdummy \textit{Verizon} lnspeed \textit{Log(DownloadSpeed)} inter_lnspeedvdummy \textit{Verizon*Log(DownloadSpeed)} lnchannel \textit{Log(NumChannels)} inter_lnchannel \textit{Verizon*Log(NumChannels)} lnincome \textit{Log(Income)})
estimates clear

