import excel TV.xlsx, clear
rename A type
rename B hhcomsub
rename C address
rename D zipcode
rename E channel1
rename F price1
rename G term1
rename H channel2
rename I price2
rename J term2
rename K channel3
rename L price3
rename M term3
rename N channel4
rename O price4
rename P term4
rename Q channel5
rename R price5
rename S term5
rename T channel6
rename U price6
rename V term6
rename W channel7
rename X price7
rename Y term7
rename Z channel8
rename AA price8
rename AB term8
rename AC channel9
rename AD price9
rename AE term9
rename AF channel10
rename AG price10
rename AH term10

* Reshape
egen uniqadd=group(address zipcode)
reshape long price term channel, i(uniqadd) j(j)
drop if channel==""

* Clean price and contract term
destring price, replace ignore("$")
replace term="0" if strpos(term,"No Term")!=0
replace term="1" if strpos(term,"1-Year")!=0
replace term="2" if strpos(term,"2-Year")!=0
destring term, replace

* Make hhcomsub dummy
replace hhcomsub="0" if hhcomsub=="Not Subscriber"
replace hhcomsub="1" if hhcomsub=="Subscriber"
destring hhcomsub, replace

* Drop package/channel errors
gen ones=1
egen packagecount=total(ones),by(channel)
tab packagecount
drop if packagecount<500

* Latin dummy
gen latin=0
replace latin=1 if strpos(channel, "Latino")!=0

* Correct prices for term
replace price=price+10 if term==1

* Correct for different names for same type of package
replace channel="10" if strpos(channel, "Basic")!=0 & strpos(channel, "Latino")==0
replace channel="100" if strpos(channel, "Economy")!=0 & strpos(channel, "Latino")==0
replace channel="140" if strpos(channel, "Starter")!=0 & strpos(channel, "Latino")==0
replace channel="220" if strpos(channel, "Preferred")!=0 & strpos(channel, "Latino")==0
replace channel="260" if strpos(channel, "Premier")!=0 & strpos(channel, "Latino")==0
replace channel="10" if strpos(channel, "Basic")!=0 & strpos(channel, "Latino")!=0
replace channel="130" if strpos(channel, "Economy")!=0 & strpos(channel, "Latino")!=0 & strpos(channel, "Economy Plus")==0
replace channel="190" if strpos(channel, "Economy Plus")!=0 & strpos(channel, "Latino")!=0
replace channel="200" if strpos(channel, "Starter")!=0 & strpos(channel, "Latino")!=0
destring channel, replace

* Merging 
merge m:m zipcode using VerizonZipcode.dta
keep if _m==3
drop _m

* Drop areas Verizon sold to Frontier
drop if dmaname=="FT.MYERS-NAPLES"
drop if dmaname=="TAMPA-ST.PETE(SARASOTA)"

merge m:m zipcode using zipincome2016.dta
keep if _m==3
drop _m

merge m:m zipcode using BellGTEzipcode.dta
drop _m

merge m:m address zipcode using VerizonHHSubs.dta
drop if _m==2
drop _m

* One stop shopping TABLE 1
preserve
collapse hhcomsub hhversub vdummy, by(uniqadd)
replace hhversub=0 if hhversub==.
gen bothsub=0
replace bothsub=1 if hhcomsub==1 & hhversub==1
gen onlycom=0
replace onlycom=1 if hhcomsub==1 & hhversub!=1
gen onlyver=0
replace onlyver=1 if hhcomsub==0 & hhversub==1
gen none=0
replace none=0 if hhcomsub!=1 & hhversub!=1
summ bothsub onlycom onlyver none if vdummy==0
summ bothsub onlycom onlyver none if vdummy==1
restore

merge m:m zipcode using BellGTEzipcode.dta
drop _m

* Drop basic when more expensive than Economy
drop if channel==10 & price>29.99

estimates clear
gen lnprice=log(price)
gen lnchannel=log(channel)
gen lnincome=log(meanincome)
egen uniqadd_channel_group = group(uniqadd channel)

* Create household-level measures
egen numchannels=total(ones), by(uniqadd)
gen lnnumchannels=log(numchannels)

egen medchanneloffered=median(channel), by(uniqadd)
egen medpriceoffered=median(price), by(uniqadd)
egen avgchannelsoffered=mean(channel), by(uniqadd)
egen avgpriceoffered=mean(price), by(uniqadd)
gen lnavgchannelsoffered=log(avgchannelsoffered)

egen numchannelsd=sd(channel), by(uniqadd)
egen pricesd=sd(price), by(uniqadd)
gen lnnumchannelsd=log(numchannelsd)

gen cv=numchannelsd/avgchannelsoffered
gen pricecv=pricesd/avgpriceoffered

gen mq=0
replace mq=1 if channel==260
egen maxqual=max(mq), by(uniqadd)

* Table 3
preserve
collapse maxqual numchannels medchanneloffered medpriceoffered avgchannelsoffered avgpriceoffered numchannelsd pricesd vdummy cv pricecv, by(uniqadd)
egen numchannelsofferedsd=sd(numchannels), by(vdummy maxqual)
egen avgnumchannelsoffered_agg=mean(numchannels)
gen cv_agg=numchannelsofferedsd/avgnumchannelsoffered

summ medchanneloffered avgchannelsoffered cv if vdummy==0
summ medchanneloffered avgchannelsoffered cv if vdummy==1
summ medpriceoffered avgpriceoffered pricecv if vdummy==0
summ medpriceoffered avgpriceoffered pricecv if vdummy==1
summ numchannels cv_agg if vdummy==0, d
summ numchannels cv_agg if vdummy==1, d
summ medchanneloffered avgchannelsoffered numchannelsd cv if vdummy==0 & maxqual==1
summ medchanneloffered avgchannelsoffered numchannelsd cv if vdummy==1 & maxqual==1
summ medpriceoffered avgpriceoffered pricecv if vdummy==0 & maxqual==1
summ medpriceoffered avgpriceoffered pricecv if vdummy==1 & maxqual==1
summ numchannels cv_agg if vdummy==0 & maxqual==1, d
summ numchannels cv_agg if vdummy==1 & maxqual==1, d
restore

gen inter_channelvdummy=channel*vdummy
gen inter_lnchannelvdummy=lnchannel*vdummy

* Table 6
preserve
collapse lnnumchannels lnavgchannelsoffered lnnumchannelsd vdummy lnincome (firstnm) dmaname (firstnm) zipcode, by(uniqadd)
reg lnnumchannels vdummy lnincome, cluster(zipcode)
estimates store reg0a
xi: areg lnnumchannels vdummy lnincome, absorb(dmaname) cluster(zipcode)
estimates store reg0b
reg lnavgchannelsoffered vdummy lnincome, cluster(zipcode)
estimates store reg0c
xi: areg lnavgchannelsoffered vdummy lnincome, absorb(dmaname) cluster(zipcode)
estimates store reg0d
reg lnnumchannelsd vdummy lnincome, cluster(zipcode)
estimates store reg0e
xi: areg lnnumchannelsd vdummy lnincome, absorb(dmaname) cluster(zipcode)
estimates store reg0f
estout reg0a reg0b reg0c reg0d reg0e reg0f, style(tex) stats(r2 N) cells(b(star fmt(2)) se(par fmt(2))) starlevels(* 0.10 ** 0.05 *** 0.01) varlabels(_cons Constant vdummy \textit{Verizon} lnspeed \textit{Log(DownloadSpeed)} inter_lnspeedvdummy \textit{Verizon*Log(DownloadSpeed)} lnchannel \textit{Log(NumChannels)} inter_lnchannel \textit{Verizon*Log(NumChannels)} lnincome \textit{Log(Income)})
restore

* IVs
egen dmag=group(dmaname)
egen avgadummy=mean(adummy), by(dmaname)
egen avgbelldummy=mean(avgbell), by(dmaname)
egen avggtedummy=mean(avggte), by(dmaname)
egen zipcode_n=group(zipcode)
gen z1=avgadummy*lnchannel
gen z2=avgbelldummy*lnchannel
gen z3=avggtedummy*lnchannel

* Table 8
eststo clear
estpost summ price vdummy channel meanincome avgbelldummy avggtedummy
est store a
esttab a, replace collabels(\multicolumn{1}{c}{{Mean}} \multicolumn{1}{c}{{Std.Dev.}} \multicolumn{1}{l}{{Obs}}) cells("mean(fmt(2)) sd(fmt(2)) count(fmt(0)) min(fmt(0)) max(fmt(0))") label nonumber f noobs alignment(S) booktabs

* Code for robustness to viewership as measure of quality
gen economy=0
replace economy=1 if channel==100
gen starter=0
replace starter=1 if channel==140
gen preferred=0
replace preferred=1 if channel==220
gen premier=0
replace premier=1 if channel==260

* Table 10, using number of channels as quality measure
xi: qui reg lnprice lnchannel vdummy lnincome, cluster(zipcode)
estimates store reg1a
xi: qui areg lnprice lnchannel c.lnchannel#i.vdummy, absorb(zipcode) cluster(zipcode) noomitted
estimates store reg1b
qui reghdfe lnprice lnchannel (inter_lnchannel = z2 z3) , absorb(zipcode_n) cluster(dmag)
estimates store reg1c
xi: qui reg lnprice lnchannel vdummy lnincome if maxqual==1, cluster(zipcode)
estimates store reg1d
xi: qui areg lnprice lnchannel c.lnchannel#i.vdummy if maxqual==1, absorb(zipcode) cluster(zipcode) noomitted
estimates store reg1e
qui reghdfe lnprice lnchannel (inter_lnchannel = z2 z3) if maxqual==1, absorb(zipcode_n) cluster(dmag)
estimates store reg1f
estout reg1a reg1b reg1c reg1d reg1e reg1f, style(tex) stats(r2 N) cells(b(star fmt(2)) se(par fmt(2))) starlevels(* 0.10 ** 0.05 *** 0.01) varlabels(_cons Constant vdummy \textit{Verizon} lnspeed \textit{Log(DownloadSpeed)} inter_lnspeedvdummy \textit{Verizon*Log(DownloadSpeed)} lnchannel \textit{Log(NumChannels)} inter_lnchannel \textit{Verizon*Log(NumChannels)} lnincome \textit{Log(Income)})

* Robustness to viewership as measure of quality

merge m:m economy starter preferred using ChannelBundleQualities.dta
drop _m
* Estimate qualities of intermediate
reg channelquality channel
predict yhat
replace lnchannel=log(yhat)
replace inter_lnchannel=lnchannel*vdummy
replace z2=avgbelldummy*lnchannel
replace z3=avggtedummy*lnchannel

* Table 12: Price regressions  for TV, robustness to viewership as measure of quality
xi: qui reg lnprice lnchannel vdummy lnincome, cluster(zipcode)
estimates store reg1a
xi: qui areg lnprice lnchannel c.lnchannel#i.vdummy, absorb(zipcode) cluster(zipcode) noomitted
estimates store reg1b
qui reghdfe lnprice lnchannel (inter_lnchannel = z2 z3) , absorb(zipcode_n) cluster(dmag)
estimates store reg1c
xi: qui reg lnprice lnchannel vdummy lnincome if maxqual==1, cluster(zipcode)
estimates store reg1d
xi: qui areg lnprice lnchannel c.lnchannel#i.vdummy if maxqual==1, absorb(zipcode) cluster(zipcode) noomitted
estimates store reg1e
qui reghdfe lnprice lnchannel (inter_lnchannel = z2 z3) if maxqual==1, absorb(zipcode_n) cluster(dmag)
estimates store reg1f
estout reg1a reg1b reg1c reg1d reg1e reg1f, style(tex) stats(r2 N) cells(b(star fmt(2)) se(par fmt(2))) starlevels(* 0.10 ** 0.05 *** 0.01) varlabels(_cons Constant vdummy \textit{Verizon} lnspeed \textit{Log(DownloadSpeed)} inter_lnspeedvdummy \textit{Verizon*Log(DownloadSpeed)} lnchannel \textit{Log(NumChannels)} inter_lnchannel \textit{Verizon*Log(NumChannels)} lnincome \textit{Log(Income)})

